#!/bin/sh


ETC_GRID_SEC="/etc/grid-security"
GSI_AUTHZ_FILE="$ETC_GRID_SEC/gsi-authz.conf"
GLITE_LOCATION="/opt/glite"
GLITE_LOCATION_LIB="$GLITE_LOCATION/lib"

GLOBUS_FLAVOR="gcc32"
SHARED_OBJECT_FILETYPE=".so"
GLITE_GT4_INTERFACE_SHARED_OBJECT_FILE_PREFIX="liblcas_lcmaps_gt4_mapping"

GLITE_GT4_INTERFACE_SHARED_OBJECT_FILE="$GLITE_LOCATION_LIB"/"$GLITE_GT4_INTERFACE_SHARED_OBJECT_FILE_PREFIX$SHARED_OBJECT_FILETYPE"
GLITE_GT4_GLOBUS_FLAVOR_INTERFACE_SHARED_OBJECT_FILE="$GLITE_LOCATION_LIB"/"$GLITE_GT4_INTERFACE_SHARED_OBJECT_FILE_PREFIX"_"$GLOBUS_FLAVOR$SHARED_OBJECT_FILETYPE"




writegsiauthz() {
cat > $GSI_AUTHZ_FILE << EOF
globus_mapping $GLITE_GT4_GLOBUS_FLAVOR_INTERFACE_SHARED_OBJECT_FILE lcmaps_callout
EOF

chmod 0644 $GSI_AUTHZ_FILE
}



debug() {
    echo "Using the following environment variables:"
    echo

    echo "\$ETC_GRID_SEC                                         " $ETC_GRID_SEC
    echo "\$GSI_AUTHZ_FILE                                       " $GSI_AUTHZ_FILE
    echo "\$GLITE_LOCATION                                       " $GLITE_LOCATION
    echo "\$GLITE_LOCATION                                       " $GLITE_LOCATION_LIB

    echo 
    echo "\$GLOBUS_FLAVOR                                        " $GLOBUS_FLAVOR
    echo "\$SHARED_OBJECT_FILETYPE                               " $SHARED_OBJECT_FILETYPE
    echo "\$GLITE_GT4_INTERFACE_SHARED_OBJECT_FILE_PREFIX        " $GLITE_GT4_INTERFACE_SHARED_OBJECT_FILE_PREFIX
    echo

    echo "\$GLITE_GT4_INTERFACE_SHARED_OBJECT_FILE               " $GLITE_GT4_INTERFACE_SHARED_OBJECT_FILE
    echo "\$GLITE_GT4_GLOBUS_FLAVOR_INTERFACE_SHARED_OBJECT_FILE " $GLITE_GT4_GLOBUS_FLAVOR_INTERFACE_SHARED_OBJECT_FILE
    echo 
}


install() {
    if [ -f "$GSI_AUTHZ_FILE" ]; then
        mv -v $GSI_AUTHZ_FILE $GSI_AUTHZ_FILE.is-replaced
    fi

    if [ ! -f "$GLITE_GT4_GLOBUS_FLAVOR_INTERFACE_SHARED_OBJECT_FILE" ]; then
        if [ ! -f "$GLITE_GT4_INTERFACE_SHARED_OBJECT_FILE" ]; then
            echo "Error: Interface doesn't exist at '$GLITE_GT4_INTERFACE_SHARED_OBJECT_FILE'."
            echo "Error: Please search for '$GLITE_GT4_INTERFACE_SHARED_OBJECT_FILE_PREFIX$SHARED_OBJECT_FILETYPE' and link it to '$GLITE_GT4_INTERFACE_SHARED_OBJECT_FILE_PREFIX$GLOBUS_FLAVOR$SHARED_OBJECT_FILETYPE' and adjust the '$GSI_AUTHZ_FILE' accordingly"
            exit 2;
        else
            # Link at the start place
            ln -s $GLITE_GT4_INTERFACE_SHARED_OBJECT_FILE $GLITE_GT4_GLOBUS_FLAVOR_INTERFACE_SHARED_OBJECT_FILE
        fi
    fi


    if [ ! -f $GLITE_GT4_GLOBUS_FLAVOR_INTERFACE_SHARED_OBJECT_FILE ]; then
        echo "Error: couldn't find the interface file '$GLITE_GT4_GLOBUS_FLAVOR_INTERFACE_SHARED_OBJECT_FILE' or a (sym)link to the interface"
        exit 3;
    else
        writegsiauthz;
    fi
   
}



deinstall() {
    if [ -f "$GSI_AUTHZ_FILE" ]; then
        mv -v $GSI_AUTHZ_FILE $GSI_AUTHZ_FILE.deinstalled
    fi
}


case "$1" in
    install)
        install;
    ;;

    deinstall)
        deinstall;
    ;;

    debug)
        debug;
    ;;

    *)
        echo $"Usage: $0 {install|deinstall|debug}";
        exit 1;
esac

exit 0;
